@@ -58,7 +58,7 @@ if psycopg2:
     psycopg2.extensions.register_type(psycopg2.extensions.UNICODE)
     psycopg2.extensions.register_type(psycopg2.extensions.UNICODEARRAY)
 
-logger = logging.getLogger('peewee.logger')
+logger = logging.getLogger('peewee')
 
 OP_AND = 0
 OP_OR = 1
@@ -168,11 +168,11 @@ class Leaf(object):
 
 class Q(Leaf):
     def __init__(self, lhs, op, rhs, negated=False):
+        super(Q, self).__init__()
         self.lhs = lhs
         self.op = op
         self.rhs = rhs
         self.negated = negated
-        super(Q, self).__init__()
 
     def clone(self):
         return Q(self.lhs, self.op, self.rhs, self.negated)
@@ -180,8 +180,8 @@ class Q(Leaf):
 
 class DQ(Leaf):
     def __init__(self, **query):
-        self.query = query
         super(DQ, self).__init__()
+        self.query = query
 
     def clone(self):
         return DQ(**self.query)
@@ -707,8 +707,10 @@ class QueryCompiler(object):
     def parse_q(self, q, alias_map=None):
         lhs_expr, lparams = self.parse_expr(q.lhs, alias_map)
         rhs_expr, rparams = self.parse_expr(q.rhs, alias_map)
-        not_expr = q.negated and 'NOT ' or ''
-        return '%s%s %s %s' % (not_expr, lhs_expr, self.get_op(q.op), rhs_expr), lparams + rparams
+        parsed = '%s %s %s' % (lhs_expr, self.get_op(q.op), rhs_expr)
+        if q.negated:
+            parsed = '(NOT %s)' % parsed
+        return parsed, lparams + rparams
 
     def parse_node(self, n, alias_map=None):
         query = []
@@ -896,7 +898,15 @@ class QueryCompiler(object):
     def field_sql(self, field):
         attrs = field.attributes
         attrs['column_type'] = self.get_field(field.get_db_field())
-        parts = [self.quote(field.db_column), field.template]
+        template = field.template
+
+        if isinstance(field, ForeignKeyField):
+            to_pk = field.rel_model._meta.primary_key
+            if not isinstance(to_pk, PrimaryKeyField):
+                template = to_pk.template
+                attrs.update(to_pk.attributes)
+
+        parts = [self.quote(field.db_column), template]
         if not field.null:
             parts.append('NOT NULL')
         if field.primary_key:
@@ -1576,6 +1586,8 @@ class Database(object):
 
     def create_index(self, model_class, fields, unique=False):
         qc = self.get_compiler()
+        if not isinstance(fields, (list, tuple)):
+            raise ValueError('fields passed to "create_index" must be a list or tuple: "%s"' % fields)
         field_objs = [model_class._meta.fields[f] if isinstance(f, basestring) else f for f in fields]
         return self.execute_sql(qc.create_index(model_class, field_objs, unique))
 
@@ -1729,6 +1741,7 @@ class MySQLDatabase(Database):
         return mysql.connect(db=database, **conn_kwargs)
 
     def create_foreign_key(self, model_class, field):
+        compiler = self.get_compiler()
         framing = """
             ALTER TABLE %(table)s ADD CONSTRAINT %(constraint)s
             FOREIGN KEY (%(field)s) REFERENCES %(to)s(%(to_field)s)%(cascade)s;
@@ -1736,16 +1749,16 @@ class MySQLDatabase(Database):
         db_table = model_class._meta.db_table
         constraint = 'fk_%s_%s_%s' % (
             db_table,
-            field.to._meta.db_table,
+            field.rel_model._meta.db_table,
             field.db_column,
         )
 
         query = framing % {
-            'table': self.quote(db_table),
-            'constraint': self.quote(constraint),
-            'field': self.quote(field.db_column),
-            'to': self.quote(field.to._meta.db_table),
-            'to_field': self.quote(field.to._meta.primary_key.db_column),
+            'table': compiler.quote(db_table),
+            'constraint': compiler.quote(constraint),
+            'field': compiler.quote(field.db_column),
+            'to': compiler.quote(field.rel_model._meta.db_table),
+            'to_field': compiler.quote(field.rel_model._meta.primary_key.db_column),
             'cascade': ' ON DELETE CASCADE' if field.cascade else '',
         }
 
@@ -1753,7 +1766,7 @@ class MySQLDatabase(Database):
         return super(MySQLDatabase, self).create_foreign_key(model_class, field)
 
     def get_indexes_for_table(self, table):
-        res = self.execute_sql('SHOW INDEXES IN %s;' % self.quote(table))
+        res = self.execute_sql('SHOW INDEXES IN `%s`;' % table)
         rows = sorted([(r[2], r[1] == 0) for r in res.fetchall()])
         return rows
 
@@ -1892,10 +1905,9 @@ class BaseModel(type):
 
         # replace the fields with field descriptors, calling the add_to_class hook
         for name, attr in cls.__dict__.items():
+            cls._meta.indexes = list(cls._meta.indexes)
             if isinstance(attr, Field):
                 attr.add_to_class(cls, name)
-                if attr.index:
-                    cls._meta.indexes.append(attr.name)
                 if attr.primary_key:
                     primary_key = attr
 
